@@ -812,4 +812,161 @@ def _api_functions(
 
         return faces
 
+    def experimental_h3_to_local_ij(origin, h):
+        """
+        Return local (i,j) coordinates of cell `h` in relation to `origin` cell
+
+
+        Parameters
+        ----------
+        origin : H3Cell
+            Origin/central cell for defining i,j coordinates.
+        h: H3Cell
+            Destination cell whose i,j coordinates we'd like, based off
+            of the origin cell.
+
+
+        Returns
+        -------
+        Tuple (i, j) of integer local coordinates of cell `h`
+
+
+        Implementation Notes
+        --------------------
+
+        The `origin` cell does not define (0, 0) for the IJ coordinate space.
+        (0, 0) refers to the center of the base cell containing origin at the
+        resolution of `origin`.
+        Subtracting the IJ coordinates of `origin` from every cell would get
+        you the property of (0, 0) being the `origin`.
+
+        This is done so we don't need to keep recomputing the coordinates of
+        `origin` if not needed.
+        """
+        origin = _in_scalar(origin)
+        h = _in_scalar(h)
+
+        i, j = _cy.experimental_h3_to_local_ij(origin, h)
+
+        return i, j
+
+    def experimental_local_ij_to_h3(origin, i, j):
+        """
+        Return cell at local (i,j) position relative to the `origin` cell.
+
+        Parameters
+        ----------
+        origin : H3Cell
+            Origin/central cell for defining i,j coordinates.
+        i, j: int
+            Integer coordinates with respect to `origin` cell.
+
+
+        Returns
+        -------
+        H3Cell at local (i,j) position relative to the `origin` cell
+
+
+        Implementation Notes
+        --------------------
+
+        The `origin` cell does not define (0, 0) for the IJ coordinate space.
+        (0, 0) refers to the center of the base cell containing origin at the
+        resolution of `origin`.
+        Subtracting the IJ coordinates of `origin` from every cell would get
+        you the property of (0, 0) being the `origin`.
+
+        This is done so we don't need to keep recomputing the coordinates of
+        `origin` if not needed.
+        """
+        origin = _in_scalar(origin)
+
+        h = _cy.experimental_local_ij_to_h3(origin, i, j)
+        h = _out_scalar(h)
+
+        return h
+
+    def cell_area(h, unit='km^2'):
+        """
+        Compute the spherical surface area of a specific H3 cell.
+
+        Parameters
+        ----------
+        h : H3Cell
+        unit: str
+            Unit for area result ('km^2', 'm^2', or 'rads^2')
+
+
+        Returns
+        -------
+        The area of the H3 cell in the given units
+
+
+        Implementation Notes
+        --------------------
+        This function breaks the cell into spherical triangles, and computes
+        their spherical area.
+        The function uses the spherical distance calculation given by
+        `point_dist`.
+        """
+        h = _in_scalar(h)
+
+        return _cy.cell_area(h, unit=unit)
+
+    def exact_edge_length(e, unit='km'):
+        """
+        Compute the spherical length of a specific H3 edge.
+
+        Parameters
+        ----------
+        h : H3Cell
+        unit: str
+            Unit for length result ('km', 'm', or 'rads')
+
+
+        Returns
+        -------
+        The length of the edge in the given units
+
+
+        Implementation Notes
+        --------------------
+        This function uses the spherical distance calculation given by
+        `point_dist`.
+        """
+        e = _in_scalar(e)
+
+        return _cy.edge_length(e, unit=unit)
+
+    def point_dist(point1, point2, unit='km'):
+        """
+        Compute the spherical distance between two (lat, lng) points.
+
+        todo: do we handle lat/lng points consistently in the api? what
+        about (lat1, lng1, lat2, lng2) as the input? How will this work
+        for vectorized versions?
+
+        Parameters
+        ----------
+        point1 : tuple
+            (lat, lng) tuple in degrees
+        point2 : tuple
+            (lat, lng) tuple in degrees
+        unit: str
+            Unit for distance result ('km', 'm', or 'rads')
+
+
+        Returns
+        -------
+        Spherical (or "haversine") distance between the points
+        """
+        lat1, lng1 = point1
+        lat2, lng2 = point2
+
+        return _cy.point_dist(
+            lat1, lng1,
+            lat2, lng2,
+            unit=unit
+        )
+
     _globals.update(locals())
