@@ -1,5 +1,5 @@
 /*
- * Copyright 2017-2018 Uber Technologies, Inc.
+ * Copyright 2017-2020 Uber Technologies, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,6 +25,7 @@
 #include "geoCoord.h"
 #include "h3Index.h"
 #include "test.h"
+#include "utility.h"
 
 // Fixtures
 static GeoCoord sfGeo = {0.659966917655, -2.1364398519396};
@@ -124,13 +125,31 @@ SUITE(h3UniEdge) {
     }
 
     TEST(getH3UnidirectionalEdgeFromPentagon) {
+        H3Index pentagons[NUM_PENTAGONS] = {0};
+        H3Index ring[7] = {0};
         H3Index pentagon;
-        setH3Index(&pentagon, 0, 4, 0);
-        H3Index adjacent;
-        setH3Index(&adjacent, 0, 8, 0);
+        H3Index edge;
 
-        H3Index edge = H3_EXPORT(getH3UnidirectionalEdge)(pentagon, adjacent);
-        t_assert(edge != 0, "Produces a valid edge");
+        for (int res = 0; res < MAX_H3_RES; res++) {
+            H3_EXPORT(getPentagonIndexes)(res, pentagons);
+            for (int p = 0; p < NUM_PENTAGONS; p++) {
+                pentagon = pentagons[p];
+                H3_EXPORT(kRing)(pentagon, 1, ring);
+
+                for (int i = 0; i < 7; i++) {
+                    H3Index neighbor = ring[i];
+                    if (neighbor == pentagon || neighbor == H3_NULL) continue;
+                    edge =
+                        H3_EXPORT(getH3UnidirectionalEdge)(pentagon, neighbor);
+                    t_assert(H3_EXPORT(h3UnidirectionalEdgeIsValid)(edge),
+                             "pentagon-to-neighbor is a valid edge");
+                    edge =
+                        H3_EXPORT(getH3UnidirectionalEdge)(neighbor, pentagon);
+                    t_assert(H3_EXPORT(h3UnidirectionalEdgeIsValid)(edge),
+                             "neighbor-to-pentagon is a valid edge");
+                }
+            }
+        }
     }
 
     TEST(h3UnidirectionalEdgeIsValid) {
@@ -228,9 +247,7 @@ SUITE(h3UniEdge) {
         const int expectedVertices[][2] = {{3, 4}, {1, 2}, {2, 3},
                                            {5, 0}, {4, 5}, {0, 1}};
 
-        // TODO: The current implementation relies on lat/lon comparison and
-        // fails on resolutions finer than 12
-        for (int res = 0; res < 13; res++) {
+        for (int res = 0; res < MAX_H3_RES; res++) {
             sf = H3_EXPORT(geoToH3)(&sfGeo, res);
             H3_EXPORT(h3ToGeoBoundary)(sf, &boundary);
             H3_EXPORT(getH3UnidirectionalEdgesFromHexagon)(sf, edges);
@@ -259,9 +276,7 @@ SUITE(h3UniEdge) {
         const int expectedVertices[][3] = {{-1, -1, -1}, {2, 3, 4}, {4, 5, 6},
                                            {8, 9, 0},    {6, 7, 8}, {0, 1, 2}};
 
-        // TODO: The current implementation relies on lat/lon comparison and
-        // fails on resolutions finer than 12
-        for (int res = 1; res < 13; res += 2) {
+        for (int res = 1; res < MAX_H3_RES; res += 2) {
             setH3Index(&pentagon, res, 24, 0);
             H3_EXPORT(h3ToGeoBoundary)(pentagon, &boundary);
             H3_EXPORT(getH3UnidirectionalEdgesFromHexagon)(pentagon, edges);
@@ -299,9 +314,7 @@ SUITE(h3UniEdge) {
         const int expectedVertices[][3] = {{-1, -1}, {1, 2}, {2, 3},
                                            {4, 0},   {3, 4}, {0, 1}};
 
-        // TODO: The current implementation relies on lat/lon comparison and
-        // fails on resolutions finer than 12
-        for (int res = 0; res < 12; res += 2) {
+        for (int res = 0; res < MAX_H3_RES; res += 2) {
             setH3Index(&pentagon, res, 24, 0);
             H3_EXPORT(h3ToGeoBoundary)(pentagon, &boundary);
             H3_EXPORT(getH3UnidirectionalEdgesFromHexagon)(pentagon, edges);
